==> jc-1.4.0.tar.gz: java/awt/CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem.h <==
// public class java.awt.CheckboxMenuItem$AccessibleAWTCheckboxMenuItem

// class file dependencies
// @dep_class b30bfe4fdf7efdf3 java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem
// @dep_class 1a6b784cf6e839c6 java_awt_MenuComponent__24AccessibleAWTMenuComponent
// @dep_class 713b3d350e77c7e5 java_awt_MenuItem__24AccessibleAWTMenuItem
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_MenuItem__24AccessibleAWTMenuItem

#include "java/awt/MenuItem__24AccessibleAWTMenuItem.h"

#ifndef _JC_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem_H_
#define _JC_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem_H_

// Forward structure declarations
struct _jc_java_awt_CheckboxMenuItem$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object;

typedef const struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods;
typedef const struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable;
typedef const struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype;

// Constructors
extern void _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$method$_init$47f1bd785ecf7f11(_jc_env *, struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object *, struct _jc_java_awt_CheckboxMenuItem$object *);

// Virtual methods structure
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods {
};

// Vtable
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$vmethods	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
	_jc_java_awt_MenuItem__24AccessibleAWTMenuItem$vmethods	java_awt_MenuItem__24AccessibleAWTMenuItem;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods	java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem;
};

// Vtype
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype {
	_jc_type			type;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs {
	struct _jc_java_awt_CheckboxMenuItem$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs {
    _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs	java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_refs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_refs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_nonrefs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_nonrefs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs	java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem;
};

// Object instance structure
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object {
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype	*vtype;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$class_object;

#endif	/* _JC_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem_H_ */

==> jc-1.4.6.tar.gz: java/awt/CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem.h <==
// public class java.awt.CheckboxMenuItem$AccessibleAWTCheckboxMenuItem

// class file dependencies
// @dep_class b30bfe4fdf7efdf3 java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem
// @dep_class 8b7c1e30849dcda2 java_awt_MenuComponent__24AccessibleAWTMenuComponent
// @dep_class 3e534b8a534026e0 java_awt_MenuItem__24AccessibleAWTMenuItem
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class d2c97b9b1866e7b0 javax_accessibility_AccessibleContext

// header file dependencies
// @dep_header java_awt_MenuItem__24AccessibleAWTMenuItem

#include "java/awt/MenuItem__24AccessibleAWTMenuItem.h"

#ifndef _JC_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem_H_
#define _JC_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem_H_

// Forward structure declarations
struct _jc_java_awt_CheckboxMenuItem$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs;
typedef struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object;

typedef const struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods;
typedef const struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable;
typedef const struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype;

// Constructors
extern void _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$method$_init$47f1bd785ecf7f11(_jc_env *, struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object *, struct _jc_java_awt_CheckboxMenuItem$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods {
};

// Vtable
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_accessibility_AccessibleContext$vmethods	javax_accessibility_AccessibleContext;
	_jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$vmethods	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
	_jc_java_awt_MenuItem__24AccessibleAWTMenuItem$vmethods	java_awt_MenuItem__24AccessibleAWTMenuItem;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vmethods	java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem;
};

// Vtype
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype {
	_jc_type			type;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs {
	struct _jc_java_awt_CheckboxMenuItem$object	*this;
};

// Reference instance fields (object)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs {
    _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_refs	java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_refs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_refs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_javax_accessibility_AccessibleContext$sub_refs	javax_accessibility_AccessibleContext;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_accessibility_AccessibleContext$sub_nonrefs	javax_accessibility_AccessibleContext;
    _jc_java_awt_MenuComponent__24AccessibleAWTMenuComponent$sub_nonrefs	java_awt_MenuComponent__24AccessibleAWTMenuComponent;
    _jc_java_awt_MenuItem__24AccessibleAWTMenuItem$sub_nonrefs	java_awt_MenuItem__24AccessibleAWTMenuItem;
    _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$sub_nonrefs	java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem;
};

// Object instance structure
struct _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$object {
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype	*vtype;
	_jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$vtype _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem$class_object;

#endif	/* _JC_java_awt_CheckboxMenuItem__24AccessibleAWTCheckboxMenuItem_H_ */
